# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.1.2~ce4aacf',
    built_at='2024-01-08 13:50:03Z',
    sha='ce4aacf8b51912543720f49d8af2d89d1fb41fd2',
    branch='HEAD',
    tag='v4.1.2',
)
